@@ -34,6 +34,7 @@ module Aws::SSOOIDC
   # * {InvalidClientException}
   # * {InvalidClientMetadataException}
   # * {InvalidGrantException}
+  # * {InvalidRedirectUriException}
   # * {InvalidRequestException}
   # * {InvalidRequestRegionException}
   # * {InvalidScopeException}
@@ -61,6 +62,11 @@ module Aws::SSOOIDC
         @data[:error]
       end
 
+      # @return [String]
+      def reason
+        @data[:reason]
+      end
+
       # @return [String]
       def error_description
         @data[:error_description]
@@ -187,6 +193,26 @@ module Aws::SSOOIDC
       end
     end
 
+    class InvalidRedirectUriException < ServiceError
+
+      # @param [Seahorse::Client::RequestContext] context
+      # @param [String] message
+      # @param [Aws::SSOOIDC::Types::InvalidRedirectUriException] data
+      def initialize(context, message, data = Aws::EmptyStructure.new)
+        super(context, message, data)
+      end
+
+      # @return [String]
+      def error
+        @data[:error]
+      end
+
+      # @return [String]
+      def error_description
+        @data[:error_description]
+      end
+    end
+
     class InvalidRequestException < ServiceError
 
       # @param [Seahorse::Client::RequestContext] context
@@ -201,6 +227,11 @@ module Aws::SSOOIDC
         @data[:error]
       end
 
+      # @return [String]
+      def reason
+        @data[:reason]
+      end
+
       # @return [String]
       def error_description
         @data[:error_description]
